@@ -7,21 +7,14 @@ from scipy import sparse
 from scipy.optimize import root_scalar
 from tqdm.auto import tqdm
 
-from sklearn.base import (
-    RegressorMixin,
-    TransformerMixin,
-)
+from sklearn.base import RegressorMixin, TransformerMixin
 from sklearn.linear_model._base import LinearModel, _preprocess_data
 from sklearn.linear_model._coordinate_descent import _alpha_grid as _lasso_alpha_grid
 from sklearn.linear_model._coordinate_descent import _path_residuals
 from sklearn.model_selection import check_cv
 from sklearn.utils.extmath import safe_sparse_dot
 from sklearn.utils.fixes import _joblib_parallel_args
-from sklearn.utils.validation import (
-    check_array,
-    check_is_fitted,
-    column_or_1d,
-)
+from sklearn.utils.validation import check_array, check_is_fitted, column_or_1d
 
 from ._base import SGLBaseEstimator
 from ._prox import _soft_threshold
@@ -72,7 +65,7 @@ class SGL(SGLBaseEstimator, RegressorMixin, LinearModel):
         Maximum number of iterations for PGD solver.
 
     tol : float, default=1e-7
-        Stopping criterion. Convergence tolerance for PGD algorithm.
+        Stopping criterion. Convergence tolerance for the ``copt`` proximal gradient solver
 
     warm_start : bool, default=False
         If set to ``True``, reuse the solution of the previous call to ``fit``
@@ -254,7 +247,6 @@ def _alpha_grid(
 
     groups = check_groups(groups, X, allow_overlap=False, fit_intercept=False)
 
-    print(scale_l2_by)
     if scale_l2_by not in ["group_length", None]:
         raise ValueError(
             "scale_l2_by must be 'group_length' or None; " "got {0}".format(scale_l2_by)
@@ -529,6 +521,9 @@ def sgl_path(
 class SGLCV(LinearModel, RegressorMixin, TransformerMixin):
     """Iterative SGL model fitting along a regularization path.
 
+    See the scikit-learn glossary entry for `cross-validation estimator
+    <https://scikit-learn.org/stable/glossary.html#term-cross-validation-estimator>`_
+
     Parameters
     ----------
     l1_ratio : float or list of float, default=1.0
@@ -584,14 +579,14 @@ class SGLCV(LinearModel, RegressorMixin, TransformerMixin):
         If True, the regressors X will be normalized before regression by
         subtracting the mean and dividing by the l2-norm.
         If you wish to standardize, please use
-        :class:`sklearn.preprocessing.StandardScaler` before calling ``fit``
+        :class:`sklearn:sklearn.preprocessing.StandardScaler` before calling ``fit``
         on an estimator with ``normalize=False``.
 
     max_iter : int, default=1000
         The maximum number of iterations
 
     tol : float, default=1e-7
-        The tolerance for the SGL solver
+        Stopping criterion. Convergence tolerance for the ``copt`` proximal gradient solver
 
     cv : int, cross-validation generator or iterable, default=None
         Determines the cross-validation splitting strategy.
@@ -602,10 +597,11 @@ class SGLCV(LinearModel, RegressorMixin, TransformerMixin):
         - an sklearn `CV splitter <https://scikit-learn.org/stable/glossary.html#term-cv-splitter>`_,
         - An iterable yielding (train, test) splits as arrays of indices.
 
-        For int/None inputs, :class:`KFold` is used.
+        For int/None inputs, :class:`sklearn:sklearn.model_selection.KFold` is used.
 
-        Refer to the scikit-learn User Guide for the various
-        cross-validation strategies that can be used here.
+        Refer to the :ref:`scikit-learn User Guide
+        <sklearn:cross_validation>` for the various cross-validation
+        strategies that can be used here.
 
     copy_X : bool, default=True
         If ``True``, X will be copied; else, it may be overwritten.
@@ -615,14 +611,9 @@ class SGLCV(LinearModel, RegressorMixin, TransformerMixin):
 
     n_jobs : int, default=None
         Number of CPUs to use during the cross validation.
-        ``None`` means 1 unless in a :obj:`joblib.parallel_backend` context.
+        ``None`` means 1 unless in a :obj:`joblib:joblib.parallel_backend` context.
         ``-1`` means using all processors.
 
-    random_state : int, RandomState instance, default=None
-        The seed of the pseudo random number generator that selects a random
-        feature to update. Used when ``selection`` == 'random'.
-        Pass an int for reproducible output across multiple function calls.
-
     Attributes
     ----------
     alpha_ : float
